@@ -32,11 +32,11 @@ def ddt(cls):
             for index, case_data in enumerate(getattr(func, "PARAMS")):
                 new_test_name = _create_test_name(index, name)
                 if isinstance(case_data, dict) and case_data.get("title"):
-                    test_desc = case_data.get("title")
+                    test_desc = str(case_data.get("title"))
                 elif isinstance(case_data, dict) and case_data.get("desc"):
-                    test_desc = case_data.get("desc")
+                    test_desc = str(case_data.get("desc"))
                 elif (not isinstance(case_data, str)) and hasattr(case_data, 'title'):
-                    test_desc = case_data.title
+                    test_desc = str(case_data.title)
                 else:
                     test_desc = func.__doc__
 
